==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ListValueBuilder.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ListValueBuilder extends ListValueFluentImpl<ListValueBuilder> implements VisitableBuilder<ListValue,ListValueBuilder>{
  public ListValueBuilder() {
    this(false);
  }
  public ListValueBuilder(Boolean validationEnabled) {
    this(new ListValue(), validationEnabled);
  }
  public ListValueBuilder(ListValueFluent<?> fluent) {
    this(fluent, false);
  }
  public ListValueBuilder(ListValueFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ListValue(), validationEnabled);
  }
  public ListValueBuilder(ListValueFluent<?> fluent,ListValue instance) {
    this(fluent, instance, false);
  }
  public ListValueBuilder(ListValueFluent<?> fluent,ListValue instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withValues(instance.getValues());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ListValueBuilder(ListValue instance) {
    this(instance,false);
  }
  public ListValueBuilder(ListValue instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withValues(instance.getValues());
    }
    this.validationEnabled = validationEnabled; 
  }
  ListValueFluent<?> fluent;
  Boolean validationEnabled;
  public ListValue build() {
    ListValue buildable = new ListValue(fluent.getValues());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.0-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ListValueBuilder.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ListValueBuilder extends ListValueFluent<ListValueBuilder> implements VisitableBuilder<ListValue,ListValueBuilder>{
  public ListValueBuilder() {
    this(false);
  }
  public ListValueBuilder(Boolean validationEnabled) {
    this(new ListValue(), validationEnabled);
  }
  public ListValueBuilder(ListValueFluent<?> fluent) {
    this(fluent, false);
  }
  public ListValueBuilder(ListValueFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ListValue(), validationEnabled);
  }
  public ListValueBuilder(ListValueFluent<?> fluent,ListValue instance) {
    this(fluent, instance, false);
  }
  public ListValueBuilder(ListValueFluent<?> fluent,ListValue instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ListValue());

    if (instance != null) {
      fluent.withValues(instance.getValues());
      fluent.withValues(instance.getValues());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ListValueBuilder(ListValue instance) {
    this(instance,false);
  }
  public ListValueBuilder(ListValue instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ListValue());

    if (instance != null) {
      this.withValues(instance.getValues());
      this.withValues(instance.getValues());
    }
    this.validationEnabled = validationEnabled; 
  }
  ListValueFluent<?> fluent;
  Boolean validationEnabled;
  public ListValue build() {
    ListValue buildable = new ListValue(fluent.buildValues());
    return buildable;
  }
  
}
